import typing

import typing_extensions

_list = list

@typing.type_check_only
class DetectLanguageRequest(typing_extensions.TypedDict, total=False):
    q: _list[str]

@typing.type_check_only
class DetectionsListResponse(typing_extensions.TypedDict, total=False):
    detections: _list[DetectionsResource]

@typing.type_check_only
class DetectionsResource(dict[str, typing.Any]): ...

@typing.type_check_only
class GetSupportedLanguagesRequest(typing_extensions.TypedDict, total=False):
    target: str

@typing.type_check_only
class LanguagesListResponse(typing_extensions.TypedDict, total=False):
    languages: _list[LanguagesResource]

@typing.type_check_only
class LanguagesResource(typing_extensions.TypedDict, total=False):
    language: str
    name: str

@typing.type_check_only
class TranslateTextRequest(typing_extensions.TypedDict, total=False):
    format: str
    model: str
    q: _list[str]
    source: str
    target: str

@typing.type_check_only
class TranslationsListResponse(typing_extensions.TypedDict, total=False):
    translations: _list[TranslationsResource]

@typing.type_check_only
class TranslationsResource(typing_extensions.TypedDict, total=False):
    detectedSourceLanguage: str
    model: str
    translatedText: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2AllowByDefault(
    typing_extensions.TypedDict, total=False
):
    disallowedRegions: _list[str]

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2AllowlistOnly(
    typing_extensions.TypedDict, total=False
):
    allowedRegions: _list[str]

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2Anonymous(
    typing_extensions.TypedDict, total=False
):
    enabled: bool

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2AppleSignInConfig(
    typing_extensions.TypedDict, total=False
):
    bundleIds: _list[str]
    codeFlowConfig: GoogleCloudIdentitytoolkitAdminV2CodeFlowConfig

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2BlockingFunctionsConfig(
    typing_extensions.TypedDict, total=False
):
    forwardInboundCredentials: GoogleCloudIdentitytoolkitAdminV2ForwardInboundCredentials
    triggers: dict[str, typing.Any]

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2ClientConfig(
    typing_extensions.TypedDict, total=False
):
    apiKey: str
    firebaseSubdomain: str
    permissions: GoogleCloudIdentitytoolkitAdminV2Permissions

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2ClientPermissionConfig(
    typing_extensions.TypedDict, total=False
):
    permissions: GoogleCloudIdentitytoolkitAdminV2ClientPermissions

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2ClientPermissions(
    typing_extensions.TypedDict, total=False
):
    disabledUserDeletion: bool
    disabledUserSignup: bool

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2CodeFlowConfig(
    typing_extensions.TypedDict, total=False
):
    keyId: str
    privateKey: str
    teamId: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2Config(typing_extensions.TypedDict, total=False):
    authorizedDomains: _list[str]
    autodeleteAnonymousUsers: bool
    blockingFunctions: GoogleCloudIdentitytoolkitAdminV2BlockingFunctionsConfig
    client: GoogleCloudIdentitytoolkitAdminV2ClientConfig
    mfa: GoogleCloudIdentitytoolkitAdminV2MultiFactorAuthConfig
    monitoring: GoogleCloudIdentitytoolkitAdminV2MonitoringConfig
    multiTenant: GoogleCloudIdentitytoolkitAdminV2MultiTenantConfig
    name: str
    notification: GoogleCloudIdentitytoolkitAdminV2NotificationConfig
    quota: GoogleCloudIdentitytoolkitAdminV2QuotaConfig
    signIn: GoogleCloudIdentitytoolkitAdminV2SignInConfig
    smsRegionConfig: GoogleCloudIdentitytoolkitAdminV2SmsRegionConfig
    subtype: typing_extensions.Literal[
        "SUBTYPE_UNSPECIFIED", "IDENTITY_PLATFORM", "FIREBASE_AUTH"
    ]

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2DefaultSupportedIdp(
    typing_extensions.TypedDict, total=False
):
    description: str
    idpId: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2DefaultSupportedIdpConfig(
    typing_extensions.TypedDict, total=False
):
    appleSignInConfig: GoogleCloudIdentitytoolkitAdminV2AppleSignInConfig
    clientId: str
    clientSecret: str
    enabled: bool
    name: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2DnsInfo(
    typing_extensions.TypedDict, total=False
):
    customDomain: str
    customDomainState: typing_extensions.Literal[
        "VERIFICATION_STATE_UNSPECIFIED",
        "NOT_STARTED",
        "IN_PROGRESS",
        "FAILED",
        "SUCCEEDED",
    ]
    domainVerificationRequestTime: str
    pendingCustomDomain: str
    useCustomDomain: bool

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2Email(typing_extensions.TypedDict, total=False):
    enabled: bool
    passwordRequired: bool

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2EmailTemplate(
    typing_extensions.TypedDict, total=False
):
    body: str
    bodyFormat: typing_extensions.Literal[
        "BODY_FORMAT_UNSPECIFIED", "PLAIN_TEXT", "HTML"
    ]
    customized: bool
    replyTo: str
    senderDisplayName: str
    senderLocalPart: str
    subject: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2ForwardInboundCredentials(
    typing_extensions.TypedDict, total=False
):
    accessToken: bool
    idToken: bool
    refreshToken: bool

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2HashConfig(
    typing_extensions.TypedDict, total=False
):
    algorithm: typing_extensions.Literal[
        "HASH_ALGORITHM_UNSPECIFIED",
        "HMAC_SHA256",
        "HMAC_SHA1",
        "HMAC_MD5",
        "SCRYPT",
        "PBKDF_SHA1",
        "MD5",
        "HMAC_SHA512",
        "SHA1",
        "BCRYPT",
        "PBKDF2_SHA256",
        "SHA256",
        "SHA512",
        "STANDARD_SCRYPT",
    ]
    memoryCost: int
    rounds: int
    saltSeparator: str
    signerKey: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2IdpCertificate(
    typing_extensions.TypedDict, total=False
):
    x509Certificate: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2IdpConfig(
    typing_extensions.TypedDict, total=False
):
    idpCertificates: _list[GoogleCloudIdentitytoolkitAdminV2IdpCertificate]
    idpEntityId: str
    signRequest: bool
    ssoUrl: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2InboundSamlConfig(
    typing_extensions.TypedDict, total=False
):
    displayName: str
    enabled: bool
    idpConfig: GoogleCloudIdentitytoolkitAdminV2IdpConfig
    name: str
    spConfig: GoogleCloudIdentitytoolkitAdminV2SpConfig

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2Inheritance(
    typing_extensions.TypedDict, total=False
):
    emailSendingConfig: bool

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2InitializeIdentityPlatformRequest(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2InitializeIdentityPlatformResponse(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2ListDefaultSupportedIdpConfigsResponse(
    typing_extensions.TypedDict, total=False
):
    defaultSupportedIdpConfigs: _list[
        GoogleCloudIdentitytoolkitAdminV2DefaultSupportedIdpConfig
    ]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2ListDefaultSupportedIdpsResponse(
    typing_extensions.TypedDict, total=False
):
    defaultSupportedIdps: _list[GoogleCloudIdentitytoolkitAdminV2DefaultSupportedIdp]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2ListInboundSamlConfigsResponse(
    typing_extensions.TypedDict, total=False
):
    inboundSamlConfigs: _list[GoogleCloudIdentitytoolkitAdminV2InboundSamlConfig]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2ListOAuthIdpConfigsResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    oauthIdpConfigs: _list[GoogleCloudIdentitytoolkitAdminV2OAuthIdpConfig]

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2ListTenantsResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    tenants: _list[GoogleCloudIdentitytoolkitAdminV2Tenant]

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2MonitoringConfig(
    typing_extensions.TypedDict, total=False
):
    requestLogging: GoogleCloudIdentitytoolkitAdminV2RequestLogging

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2MultiFactorAuthConfig(
    typing_extensions.TypedDict, total=False
):
    enabledProviders: _list[str]
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "DISABLED", "ENABLED", "MANDATORY"
    ]

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2MultiTenantConfig(
    typing_extensions.TypedDict, total=False
):
    allowTenants: bool
    defaultTenantLocation: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2NotificationConfig(
    typing_extensions.TypedDict, total=False
):
    defaultLocale: str
    sendEmail: GoogleCloudIdentitytoolkitAdminV2SendEmail
    sendSms: GoogleCloudIdentitytoolkitAdminV2SendSms

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2OAuthIdpConfig(
    typing_extensions.TypedDict, total=False
):
    clientId: str
    clientSecret: str
    displayName: str
    enabled: bool
    issuer: str
    name: str
    responseType: GoogleCloudIdentitytoolkitAdminV2OAuthResponseType

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2OAuthResponseType(
    typing_extensions.TypedDict, total=False
):
    code: bool
    idToken: bool
    token: bool

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2Permissions(
    typing_extensions.TypedDict, total=False
):
    disabledUserDeletion: bool
    disabledUserSignup: bool

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2PhoneNumber(
    typing_extensions.TypedDict, total=False
):
    enabled: bool
    testPhoneNumbers: dict[str, typing.Any]

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2QuotaConfig(
    typing_extensions.TypedDict, total=False
):
    signUpQuotaConfig: GoogleCloudIdentitytoolkitAdminV2TemporaryQuota

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2RequestLogging(
    typing_extensions.TypedDict, total=False
):
    enabled: bool

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2SendEmail(
    typing_extensions.TypedDict, total=False
):
    callbackUri: str
    changeEmailTemplate: GoogleCloudIdentitytoolkitAdminV2EmailTemplate
    dnsInfo: GoogleCloudIdentitytoolkitAdminV2DnsInfo
    legacyResetPasswordTemplate: GoogleCloudIdentitytoolkitAdminV2EmailTemplate
    method: typing_extensions.Literal["METHOD_UNSPECIFIED", "DEFAULT", "CUSTOM_SMTP"]
    resetPasswordTemplate: GoogleCloudIdentitytoolkitAdminV2EmailTemplate
    revertSecondFactorAdditionTemplate: GoogleCloudIdentitytoolkitAdminV2EmailTemplate
    smtp: GoogleCloudIdentitytoolkitAdminV2Smtp
    verifyEmailTemplate: GoogleCloudIdentitytoolkitAdminV2EmailTemplate

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2SendSms(
    typing_extensions.TypedDict, total=False
):
    smsTemplate: GoogleCloudIdentitytoolkitAdminV2SmsTemplate
    useDeviceLocale: bool

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2SignInConfig(
    typing_extensions.TypedDict, total=False
):
    allowDuplicateEmails: bool
    anonymous: GoogleCloudIdentitytoolkitAdminV2Anonymous
    email: GoogleCloudIdentitytoolkitAdminV2Email
    hashConfig: GoogleCloudIdentitytoolkitAdminV2HashConfig
    phoneNumber: GoogleCloudIdentitytoolkitAdminV2PhoneNumber

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2SmsRegionConfig(
    typing_extensions.TypedDict, total=False
):
    allowByDefault: GoogleCloudIdentitytoolkitAdminV2AllowByDefault
    allowlistOnly: GoogleCloudIdentitytoolkitAdminV2AllowlistOnly

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2SmsTemplate(
    typing_extensions.TypedDict, total=False
):
    content: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2Smtp(typing_extensions.TypedDict, total=False):
    host: str
    password: str
    port: int
    securityMode: typing_extensions.Literal[
        "SECURITY_MODE_UNSPECIFIED", "SSL", "START_TLS"
    ]
    senderEmail: str
    username: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2SpCertificate(
    typing_extensions.TypedDict, total=False
):
    expiresAt: str
    x509Certificate: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2SpConfig(
    typing_extensions.TypedDict, total=False
):
    callbackUri: str
    spCertificates: _list[GoogleCloudIdentitytoolkitAdminV2SpCertificate]
    spEntityId: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2TemporaryQuota(
    typing_extensions.TypedDict, total=False
):
    quota: str
    quotaDuration: str
    startTime: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2Tenant(typing_extensions.TypedDict, total=False):
    allowPasswordSignup: bool
    autodeleteAnonymousUsers: bool
    client: GoogleCloudIdentitytoolkitAdminV2ClientPermissionConfig
    disableAuth: bool
    displayName: str
    enableAnonymousUser: bool
    enableEmailLinkSignin: bool
    hashConfig: GoogleCloudIdentitytoolkitAdminV2HashConfig
    inheritance: GoogleCloudIdentitytoolkitAdminV2Inheritance
    mfaConfig: GoogleCloudIdentitytoolkitAdminV2MultiFactorAuthConfig
    monitoring: GoogleCloudIdentitytoolkitAdminV2MonitoringConfig
    name: str
    smsRegionConfig: GoogleCloudIdentitytoolkitAdminV2SmsRegionConfig
    testPhoneNumbers: dict[str, typing.Any]

@typing.type_check_only
class GoogleCloudIdentitytoolkitAdminV2Trigger(
    typing_extensions.TypedDict, total=False
):
    functionUri: str
    updateTime: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV2AutoRetrievalInfo(
    typing_extensions.TypedDict, total=False
):
    appSignatureHash: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV2FinalizeMfaEnrollmentRequest(
    typing_extensions.TypedDict, total=False
):
    displayName: str
    idToken: str
    phoneVerificationInfo: GoogleCloudIdentitytoolkitV2FinalizeMfaPhoneRequestInfo
    tenantId: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV2FinalizeMfaEnrollmentResponse(
    typing_extensions.TypedDict, total=False
):
    idToken: str
    phoneAuthInfo: GoogleCloudIdentitytoolkitV2FinalizeMfaPhoneResponseInfo
    refreshToken: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV2FinalizeMfaPhoneRequestInfo(
    typing_extensions.TypedDict, total=False
):
    androidVerificationProof: str
    code: str
    phoneNumber: str
    sessionInfo: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV2FinalizeMfaPhoneResponseInfo(
    typing_extensions.TypedDict, total=False
):
    androidVerificationProof: str
    androidVerificationProofExpireTime: str
    phoneNumber: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV2FinalizeMfaSignInRequest(
    typing_extensions.TypedDict, total=False
):
    mfaPendingCredential: str
    phoneVerificationInfo: GoogleCloudIdentitytoolkitV2FinalizeMfaPhoneRequestInfo
    tenantId: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV2FinalizeMfaSignInResponse(
    typing_extensions.TypedDict, total=False
):
    idToken: str
    phoneAuthInfo: GoogleCloudIdentitytoolkitV2FinalizeMfaPhoneResponseInfo
    refreshToken: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV2StartMfaEnrollmentRequest(
    typing_extensions.TypedDict, total=False
):
    idToken: str
    phoneEnrollmentInfo: GoogleCloudIdentitytoolkitV2StartMfaPhoneRequestInfo
    tenantId: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV2StartMfaEnrollmentResponse(
    typing_extensions.TypedDict, total=False
):
    phoneSessionInfo: GoogleCloudIdentitytoolkitV2StartMfaPhoneResponseInfo

@typing.type_check_only
class GoogleCloudIdentitytoolkitV2StartMfaPhoneRequestInfo(
    typing_extensions.TypedDict, total=False
):
    autoRetrievalInfo: GoogleCloudIdentitytoolkitV2AutoRetrievalInfo
    iosReceipt: str
    iosSecret: str
    phoneNumber: str
    recaptchaToken: str
    safetyNetToken: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV2StartMfaPhoneResponseInfo(
    typing_extensions.TypedDict, total=False
):
    sessionInfo: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV2StartMfaSignInRequest(
    typing_extensions.TypedDict, total=False
):
    mfaEnrollmentId: str
    mfaPendingCredential: str
    phoneSignInInfo: GoogleCloudIdentitytoolkitV2StartMfaPhoneRequestInfo
    tenantId: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV2StartMfaSignInResponse(
    typing_extensions.TypedDict, total=False
):
    phoneResponseInfo: GoogleCloudIdentitytoolkitV2StartMfaPhoneResponseInfo

@typing.type_check_only
class GoogleCloudIdentitytoolkitV2WithdrawMfaRequest(
    typing_extensions.TypedDict, total=False
):
    idToken: str
    mfaEnrollmentId: str
    tenantId: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV2WithdrawMfaResponse(
    typing_extensions.TypedDict, total=False
):
    idToken: str
    refreshToken: str

@typing.type_check_only
class GoogleIamV1AuditConfig(typing_extensions.TypedDict, total=False):
    auditLogConfigs: _list[GoogleIamV1AuditLogConfig]
    service: str

@typing.type_check_only
class GoogleIamV1AuditLogConfig(typing_extensions.TypedDict, total=False):
    exemptedMembers: _list[str]
    logType: typing_extensions.Literal[
        "LOG_TYPE_UNSPECIFIED", "ADMIN_READ", "DATA_WRITE", "DATA_READ"
    ]

@typing.type_check_only
class GoogleIamV1Binding(typing_extensions.TypedDict, total=False):
    condition: GoogleTypeExpr
    members: _list[str]
    role: str

@typing.type_check_only
class GoogleIamV1GetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    options: GoogleIamV1GetPolicyOptions

@typing.type_check_only
class GoogleIamV1GetPolicyOptions(typing_extensions.TypedDict, total=False):
    requestedPolicyVersion: int

@typing.type_check_only
class GoogleIamV1Policy(typing_extensions.TypedDict, total=False):
    auditConfigs: _list[GoogleIamV1AuditConfig]
    bindings: _list[GoogleIamV1Binding]
    etag: str
    version: int

@typing.type_check_only
class GoogleIamV1SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: GoogleIamV1Policy
    updateMask: str

@typing.type_check_only
class GoogleIamV1TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class GoogleIamV1TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class GoogleProtobufEmpty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GoogleTypeExpr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Aggregation(typing_extensions.TypedDict, total=False):
    alignmentPeriod: str
    crossSeriesReducer: typing_extensions.Literal[
        "REDUCE_NONE",
        "REDUCE_MEAN",
        "REDUCE_MIN",
        "REDUCE_MAX",
        "REDUCE_SUM",
        "REDUCE_STDDEV",
        "REDUCE_COUNT",
        "REDUCE_COUNT_TRUE",
        "REDUCE_COUNT_FALSE",
        "REDUCE_FRACTION_TRUE",
        "REDUCE_PERCENTILE_99",
        "REDUCE_PERCENTILE_95",
        "REDUCE_PERCENTILE_50",
        "REDUCE_PERCENTILE_05",
    ]
    groupByFields: _list[str]
    perSeriesAligner: typing_extensions.Literal[
        "ALIGN_NONE",
        "ALIGN_DELTA",
        "ALIGN_RATE",
        "ALIGN_INTERPOLATE",
        "ALIGN_NEXT_OLDER",
        "ALIGN_MIN",
        "ALIGN_MAX",
        "ALIGN_MEAN",
        "ALIGN_COUNT",
        "ALIGN_SUM",
        "ALIGN_STDDEV",
        "ALIGN_COUNT_TRUE",
        "ALIGN_COUNT_FALSE",
        "ALIGN_FRACTION_TRUE",
        "ALIGN_PERCENTILE_99",
        "ALIGN_PERCENTILE_95",
        "ALIGN_PERCENTILE_50",
        "ALIGN_PERCENTILE_05",
        "ALIGN_PERCENT_CHANGE",
    ]

@typing.type_check_only
class AlertChart(typing_extensions.TypedDict, total=False):
    name: str

@typing.type_check_only
class Axis(typing_extensions.TypedDict, total=False):
    label: str
    scale: typing_extensions.Literal["SCALE_UNSPECIFIED", "LINEAR", "LOG10"]

@typing.type_check_only
class ChartOptions(typing_extensions.TypedDict, total=False):
    mode: typing_extensions.Literal["MODE_UNSPECIFIED", "COLOR", "X_RAY", "STATS"]

@typing.type_check_only
class CollapsibleGroup(typing_extensions.TypedDict, total=False):
    collapsed: bool

@typing.type_check_only
class Column(typing_extensions.TypedDict, total=False):
    weight: str
    widgets: _list[Widget]

@typing.type_check_only
class ColumnLayout(typing_extensions.TypedDict, total=False):
    columns: _list[Column]

@typing.type_check_only
class Dashboard(typing_extensions.TypedDict, total=False):
    columnLayout: ColumnLayout
    dashboardFilters: _list[DashboardFilter]
    displayName: str
    etag: str
    gridLayout: GridLayout
    labels: dict[str, typing.Any]
    mosaicLayout: MosaicLayout
    name: str
    rowLayout: RowLayout

@typing.type_check_only
class DashboardFilter(typing_extensions.TypedDict, total=False):
    filterType: typing_extensions.Literal[
        "FILTER_TYPE_UNSPECIFIED",
        "RESOURCE_LABEL",
        "METRIC_LABEL",
        "USER_METADATA_LABEL",
        "SYSTEM_METADATA_LABEL",
        "GROUP",
    ]
    labelKey: str
    stringValue: str
    templateVariable: str

@typing.type_check_only
class DataSet(typing_extensions.TypedDict, total=False):
    legendTemplate: str
    minAlignmentPeriod: str
    plotType: typing_extensions.Literal[
        "PLOT_TYPE_UNSPECIFIED", "LINE", "STACKED_AREA", "STACKED_BAR", "HEATMAP"
    ]
    targetAxis: typing_extensions.Literal["TARGET_AXIS_UNSPECIFIED", "Y1", "Y2"]
    timeSeriesQuery: TimeSeriesQuery

@typing.type_check_only
class DroppedLabels(typing_extensions.TypedDict, total=False):
    label: dict[str, typing.Any]

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Field(typing_extensions.TypedDict, total=False):
    cardinality: typing_extensions.Literal[
        "CARDINALITY_UNKNOWN",
        "CARDINALITY_OPTIONAL",
        "CARDINALITY_REQUIRED",
        "CARDINALITY_REPEATED",
    ]
    defaultValue: str
    jsonName: str
    kind: typing_extensions.Literal[
        "TYPE_UNKNOWN",
        "TYPE_DOUBLE",
        "TYPE_FLOAT",
        "TYPE_INT64",
        "TYPE_UINT64",
        "TYPE_INT32",
        "TYPE_FIXED64",
        "TYPE_FIXED32",
        "TYPE_BOOL",
        "TYPE_STRING",
        "TYPE_GROUP",
        "TYPE_MESSAGE",
        "TYPE_BYTES",
        "TYPE_UINT32",
        "TYPE_ENUM",
        "TYPE_SFIXED32",
        "TYPE_SFIXED64",
        "TYPE_SINT32",
        "TYPE_SINT64",
    ]
    name: str
    number: int
    oneofIndex: int
    options: _list[Option]
    packed: bool
    typeUrl: str

@typing.type_check_only
class GaugeView(typing_extensions.TypedDict, total=False):
    lowerBound: float
    upperBound: float

@typing.type_check_only
class GridLayout(typing_extensions.TypedDict, total=False):
    columns: str
    widgets: _list[Widget]

@typing.type_check_only
class HttpBody(typing_extensions.TypedDict, total=False):
    contentType: str
    data: str
    extensions: _list[dict[str, typing.Any]]

@typing.type_check_only
class ListDashboardsResponse(typing_extensions.TypedDict, total=False):
    dashboards: _list[Dashboard]
    nextPageToken: str

@typing.type_check_only
class ListLabelsRequest(typing_extensions.TypedDict, total=False):
    end: str
    match: str
    start: str

@typing.type_check_only
class ListMetricsScopesByMonitoredProjectResponse(
    typing_extensions.TypedDict, total=False
):
    metricsScopes: _list[MetricsScope]

@typing.type_check_only
class LogsPanel(typing_extensions.TypedDict, total=False):
    filter: str
    resourceNames: _list[str]

@typing.type_check_only
class MetricsScope(typing_extensions.TypedDict, total=False):
    createTime: str
    monitoredProjects: _list[MonitoredProject]
    name: str
    updateTime: str

@typing.type_check_only
class MonitoredProject(typing_extensions.TypedDict, total=False):
    createTime: str
    name: str

@typing.type_check_only
class MosaicLayout(typing_extensions.TypedDict, total=False):
    columns: int
    tiles: _list[Tile]

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OperationMetadata(typing_extensions.TypedDict, total=False):
    createTime: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "CREATED", "RUNNING", "DONE", "CANCELLED"
    ]
    updateTime: str

@typing.type_check_only
class Option(typing_extensions.TypedDict, total=False):
    name: str
    value: dict[str, typing.Any]

@typing.type_check_only
class PickTimeSeriesFilter(typing_extensions.TypedDict, total=False):
    direction: typing_extensions.Literal["DIRECTION_UNSPECIFIED", "TOP", "BOTTOM"]
    numTimeSeries: int
    rankingMethod: typing_extensions.Literal[
        "METHOD_UNSPECIFIED",
        "METHOD_MEAN",
        "METHOD_MAX",
        "METHOD_MIN",
        "METHOD_SUM",
        "METHOD_LATEST",
    ]

@typing.type_check_only
class QueryInstantRequest(typing_extensions.TypedDict, total=False):
    query: str
    time: str
    timeout: str

@typing.type_check_only
class QueryRangeRequest(typing_extensions.TypedDict, total=False):
    end: str
    query: str
    start: str
    step: str
    timeout: str

@typing.type_check_only
class QuerySeriesRequest(typing_extensions.TypedDict, total=False):
    end: str
    start: str

@typing.type_check_only
class RatioPart(typing_extensions.TypedDict, total=False):
    aggregation: Aggregation
    filter: str

@typing.type_check_only
class Row(typing_extensions.TypedDict, total=False):
    weight: str
    widgets: _list[Widget]

@typing.type_check_only
class RowLayout(typing_extensions.TypedDict, total=False):
    rows: _list[Row]

@typing.type_check_only
class Scorecard(typing_extensions.TypedDict, total=False):
    gaugeView: GaugeView
    sparkChartView: SparkChartView
    thresholds: _list[Threshold]
    timeSeriesQuery: TimeSeriesQuery

@typing.type_check_only
class SourceContext(typing_extensions.TypedDict, total=False):
    fileName: str

@typing.type_check_only
class SpanContext(typing_extensions.TypedDict, total=False):
    spanName: str

@typing.type_check_only
class SparkChartView(typing_extensions.TypedDict, total=False):
    minAlignmentPeriod: str
    sparkChartType: typing_extensions.Literal[
        "SPARK_CHART_TYPE_UNSPECIFIED", "SPARK_LINE", "SPARK_BAR"
    ]

@typing.type_check_only
class StatisticalTimeSeriesFilter(typing_extensions.TypedDict, total=False):
    numTimeSeries: int
    rankingMethod: typing_extensions.Literal[
        "METHOD_UNSPECIFIED", "METHOD_CLUSTER_OUTLIER"
    ]

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class TableDataSet(typing_extensions.TypedDict, total=False):
    minAlignmentPeriod: str
    tableDisplayOptions: TableDisplayOptions
    tableTemplate: str
    timeSeriesQuery: TimeSeriesQuery

@typing.type_check_only
class TableDisplayOptions(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Text(typing_extensions.TypedDict, total=False):
    content: str
    format: typing_extensions.Literal["FORMAT_UNSPECIFIED", "MARKDOWN", "RAW"]

@typing.type_check_only
class Threshold(typing_extensions.TypedDict, total=False):
    color: typing_extensions.Literal["COLOR_UNSPECIFIED", "YELLOW", "RED"]
    direction: typing_extensions.Literal["DIRECTION_UNSPECIFIED", "ABOVE", "BELOW"]
    label: str
    targetAxis: typing_extensions.Literal["TARGET_AXIS_UNSPECIFIED", "Y1", "Y2"]
    value: float

@typing.type_check_only
class Tile(typing_extensions.TypedDict, total=False):
    height: int
    widget: Widget
    width: int
    xPos: int
    yPos: int

@typing.type_check_only
class TimeSeriesFilter(typing_extensions.TypedDict, total=False):
    aggregation: Aggregation
    filter: str
    pickTimeSeriesFilter: PickTimeSeriesFilter
    secondaryAggregation: Aggregation
    statisticalTimeSeriesFilter: StatisticalTimeSeriesFilter

@typing.type_check_only
class TimeSeriesFilterRatio(typing_extensions.TypedDict, total=False):
    denominator: RatioPart
    numerator: RatioPart
    pickTimeSeriesFilter: PickTimeSeriesFilter
    secondaryAggregation: Aggregation
    statisticalTimeSeriesFilter: StatisticalTimeSeriesFilter

@typing.type_check_only
class TimeSeriesQuery(typing_extensions.TypedDict, total=False):
    prometheusQuery: str
    timeSeriesFilter: TimeSeriesFilter
    timeSeriesFilterRatio: TimeSeriesFilterRatio
    timeSeriesQueryLanguage: str
    unitOverride: str

@typing.type_check_only
class TimeSeriesTable(typing_extensions.TypedDict, total=False):
    dataSets: _list[TableDataSet]
    metricVisualization: typing_extensions.Literal[
        "METRIC_VISUALIZATION_UNSPECIFIED", "NUMBER", "BAR"
    ]

@typing.type_check_only
class Type(typing_extensions.TypedDict, total=False):
    fields: _list[Field]
    name: str
    oneofs: _list[str]
    options: _list[Option]
    sourceContext: SourceContext
    syntax: typing_extensions.Literal["SYNTAX_PROTO2", "SYNTAX_PROTO3"]

@typing.type_check_only
class Widget(typing_extensions.TypedDict, total=False):
    alertChart: AlertChart
    blank: Empty
    collapsibleGroup: CollapsibleGroup
    logsPanel: LogsPanel
    scorecard: Scorecard
    text: Text
    timeSeriesTable: TimeSeriesTable
    title: str
    xyChart: XyChart

@typing.type_check_only
class XyChart(typing_extensions.TypedDict, total=False):
    chartOptions: ChartOptions
    dataSets: _list[DataSet]
    thresholds: _list[Threshold]
    timeshiftDuration: str
    xAxis: Axis
    y2Axis: Axis
    yAxis: Axis



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CloudRunResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class NamespacesResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class JobsResource(googleapiclient.discovery.Resource):
            def create(
                self, *, parent: str, body: Job = ..., **kwargs: typing.Any
            ) -> JobHttpRequest: ...
            def delete(
                self,
                *,
                name: str,
                apiVersion: str = ...,
                kind: str = ...,
                propagationPolicy: str = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(self, *, name: str, **kwargs: typing.Any) -> JobHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                fieldSelector: str = ...,
                includeUninitialized: bool = ...,
                labelSelector: str = ...,
                limit: int = ...,
                resourceVersion: str = ...,
                watch: bool = ...,
                **kwargs: typing.Any
            ) -> ListJobsResponseHttpRequest: ...

        def jobs(self) -> JobsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def namespaces(self) -> NamespacesResource: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class JobHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Job: ...

@typing.type_check_only
class ListJobsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListJobsResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class OSConfigResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class GuestPoliciesResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                parent: str,
                body: GuestPolicy = ...,
                guestPolicyId: str = ...,
                **kwargs: typing.Any
            ) -> GuestPolicyHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GuestPolicyHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListGuestPoliciesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListGuestPoliciesResponseHttpRequest,
                previous_response: ListGuestPoliciesResponse,
            ) -> ListGuestPoliciesResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GuestPolicy = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> GuestPolicyHttpRequest: ...

        @typing.type_check_only
        class PatchDeploymentsResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                parent: str,
                body: PatchDeployment = ...,
                patchDeploymentId: str = ...,
                **kwargs: typing.Any
            ) -> PatchDeploymentHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> PatchDeploymentHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListPatchDeploymentsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListPatchDeploymentsResponseHttpRequest,
                previous_response: ListPatchDeploymentsResponse,
            ) -> ListPatchDeploymentsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: PatchDeployment = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> PatchDeploymentHttpRequest: ...
            def pause(
                self,
                *,
                name: str,
                body: PausePatchDeploymentRequest = ...,
                **kwargs: typing.Any
            ) -> PatchDeploymentHttpRequest: ...
            def resume(
                self,
                *,
                name: str,
                body: ResumePatchDeploymentRequest = ...,
                **kwargs: typing.Any
            ) -> PatchDeploymentHttpRequest: ...

        @typing.type_check_only
        class PatchJobsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class InstanceDetailsResource(googleapiclient.discovery.Resource):
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListPatchJobInstanceDetailsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListPatchJobInstanceDetailsResponseHttpRequest,
                    previous_response: ListPatchJobInstanceDetailsResponse,
                ) -> ListPatchJobInstanceDetailsResponseHttpRequest | None: ...

            def cancel(
                self,
                *,
                name: str,
                body: CancelPatchJobRequest = ...,
                **kwargs: typing.Any
            ) -> PatchJobHttpRequest: ...
            def execute(
                self,
                *,
                parent: str,
                body: ExecutePatchJobRequest = ...,
                **kwargs: typing.Any
            ) -> PatchJobHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> PatchJobHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListPatchJobsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListPatchJobsResponseHttpRequest,
                previous_response: ListPatchJobsResponse,
            ) -> ListPatchJobsResponseHttpRequest | None: ...
            def instanceDetails(self) -> InstanceDetailsResource: ...

        @typing.type_check_only
        class ZonesResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class InstancesResource(googleapiclient.discovery.Resource):
                def lookupEffectiveGuestPolicy(
                    self,
                    *,
                    instance: str,
                    body: LookupEffectiveGuestPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> EffectiveGuestPolicyHttpRequest: ...

            def instances(self) -> InstancesResource: ...

        def guestPolicies(self) -> GuestPoliciesResource: ...
        def patchDeployments(self) -> PatchDeploymentsResource: ...
        def patchJobs(self) -> PatchJobsResource: ...
        def zones(self) -> ZonesResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class EffectiveGuestPolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> EffectiveGuestPolicy: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class GuestPolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GuestPolicy: ...

@typing.type_check_only
class ListGuestPoliciesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListGuestPoliciesResponse: ...

@typing.type_check_only
class ListPatchDeploymentsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListPatchDeploymentsResponse: ...

@typing.type_check_only
class ListPatchJobInstanceDetailsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListPatchJobInstanceDetailsResponse: ...

@typing.type_check_only
class ListPatchJobsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListPatchJobsResponse: ...

@typing.type_check_only
class PatchDeploymentHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PatchDeployment: ...

@typing.type_check_only
class PatchJobHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PatchJob: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class DocumentResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def cancel(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def list(
                    self,
                    *,
                    name: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningListOperationsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleLongrunningListOperationsResponseHttpRequest,
                    previous_response: GoogleLongrunningListOperationsResponse,
                ) -> GoogleLongrunningListOperationsResponseHttpRequest | None: ...

            @typing.type_check_only
            class ProcessorTypesResource(googleapiclient.discovery.Resource):
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudDocumentaiV1beta3ListProcessorTypesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudDocumentaiV1beta3ListProcessorTypesResponseHttpRequest,
                    previous_response: GoogleCloudDocumentaiV1beta3ListProcessorTypesResponse,
                ) -> GoogleCloudDocumentaiV1beta3ListProcessorTypesResponseHttpRequest | None: ...

            @typing.type_check_only
            class ProcessorsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class HumanReviewConfigResource(googleapiclient.discovery.Resource):
                    def reviewDocument(
                        self,
                        *,
                        humanReviewConfig: str,
                        body: GoogleCloudDocumentaiV1beta3ReviewDocumentRequest = ...,
                        **kwargs: typing.Any
                    ) -> GoogleLongrunningOperationHttpRequest: ...

                @typing.type_check_only
                class ProcessorVersionsResource(googleapiclient.discovery.Resource):
                    def batchProcess(
                        self,
                        *,
                        name: str,
                        body: GoogleCloudDocumentaiV1beta3BatchProcessRequest = ...,
                        **kwargs: typing.Any
                    ) -> GoogleLongrunningOperationHttpRequest: ...
                    def delete(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> GoogleLongrunningOperationHttpRequest: ...
                    def deploy(
                        self,
                        *,
                        name: str,
                        body: GoogleCloudDocumentaiV1beta3DeployProcessorVersionRequest = ...,
                        **kwargs: typing.Any
                    ) -> GoogleLongrunningOperationHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> GoogleCloudDocumentaiV1beta3ProcessorVersionHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudDocumentaiV1beta3ListProcessorVersionsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: GoogleCloudDocumentaiV1beta3ListProcessorVersionsResponseHttpRequest,
                        previous_response: GoogleCloudDocumentaiV1beta3ListProcessorVersionsResponse,
                    ) -> GoogleCloudDocumentaiV1beta3ListProcessorVersionsResponseHttpRequest | None: ...
                    def process(
                        self,
                        *,
                        name: str,
                        body: GoogleCloudDocumentaiV1beta3ProcessRequest = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudDocumentaiV1beta3ProcessResponseHttpRequest: ...
                    def undeploy(
                        self,
                        *,
                        name: str,
                        body: GoogleCloudDocumentaiV1beta3UndeployProcessorVersionRequest = ...,
                        **kwargs: typing.Any
                    ) -> GoogleLongrunningOperationHttpRequest: ...

                def batchProcess(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudDocumentaiV1beta3BatchProcessRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudDocumentaiV1beta3Processor = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudDocumentaiV1beta3ProcessorHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def disable(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudDocumentaiV1beta3DisableProcessorRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def enable(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudDocumentaiV1beta3EnableProcessorRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleCloudDocumentaiV1beta3ProcessorHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudDocumentaiV1beta3ListProcessorsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudDocumentaiV1beta3ListProcessorsResponseHttpRequest,
                    previous_response: GoogleCloudDocumentaiV1beta3ListProcessorsResponse,
                ) -> GoogleCloudDocumentaiV1beta3ListProcessorsResponseHttpRequest | None: ...
                def process(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudDocumentaiV1beta3ProcessRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudDocumentaiV1beta3ProcessResponseHttpRequest: ...
                def setDefaultProcessorVersion(
                    self,
                    *,
                    processor: str,
                    body: GoogleCloudDocumentaiV1beta3SetDefaultProcessorVersionRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def humanReviewConfig(self) -> HumanReviewConfigResource: ...
                def processorVersions(self) -> ProcessorVersionsResource: ...

            def fetchProcessorTypes(
                self, *, parent: str, **kwargs: typing.Any
            ) -> GoogleCloudDocumentaiV1beta3FetchProcessorTypesResponseHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleCloudLocationLocationHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudLocationListLocationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleCloudLocationListLocationsResponseHttpRequest,
                previous_response: GoogleCloudLocationListLocationsResponse,
            ) -> GoogleCloudLocationListLocationsResponseHttpRequest | None: ...
            def operations(self) -> OperationsResource: ...
            def processorTypes(self) -> ProcessorTypesResource: ...
            def processors(self) -> ProcessorsResource: ...

        def locations(self) -> LocationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class GoogleCloudDocumentaiV1beta3FetchProcessorTypesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDocumentaiV1beta3FetchProcessorTypesResponse: ...

@typing.type_check_only
class GoogleCloudDocumentaiV1beta3ListProcessorTypesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDocumentaiV1beta3ListProcessorTypesResponse: ...

@typing.type_check_only
class GoogleCloudDocumentaiV1beta3ListProcessorVersionsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDocumentaiV1beta3ListProcessorVersionsResponse: ...

@typing.type_check_only
class GoogleCloudDocumentaiV1beta3ListProcessorsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDocumentaiV1beta3ListProcessorsResponse: ...

@typing.type_check_only
class GoogleCloudDocumentaiV1beta3ProcessResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDocumentaiV1beta3ProcessResponse: ...

@typing.type_check_only
class GoogleCloudDocumentaiV1beta3ProcessorHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDocumentaiV1beta3Processor: ...

@typing.type_check_only
class GoogleCloudDocumentaiV1beta3ProcessorVersionHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudDocumentaiV1beta3ProcessorVersion: ...

@typing.type_check_only
class GoogleCloudLocationListLocationsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudLocationListLocationsResponse: ...

@typing.type_check_only
class GoogleCloudLocationLocationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudLocationLocation: ...

@typing.type_check_only
class GoogleLongrunningListOperationsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleLongrunningListOperationsResponse: ...

@typing.type_check_only
class GoogleLongrunningOperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleLongrunningOperation: ...

@typing.type_check_only
class GoogleProtobufEmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleProtobufEmpty: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class PlaycustomappResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AccountsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class CustomAppsResource(googleapiclient.discovery.Resource):
            def create(
                self, *, account: str, body: CustomApp = ..., **kwargs: typing.Any
            ) -> CustomAppHttpRequest: ...

        def customApps(self) -> CustomAppsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def accounts(self) -> AccountsResource: ...

@typing.type_check_only
class CustomAppHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CustomApp: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AgentPool(typing_extensions.TypedDict, total=False):
    bandwidthLimit: BandwidthLimit
    displayName: str
    name: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "CREATING", "CREATED", "DELETING"
    ]

@typing.type_check_only
class AwsAccessKey(typing_extensions.TypedDict, total=False):
    accessKeyId: str
    secretAccessKey: str

@typing.type_check_only
class AwsS3CompatibleData(typing_extensions.TypedDict, total=False):
    bucketName: str
    endpoint: str
    path: str
    region: str
    s3Metadata: S3CompatibleMetadata

@typing.type_check_only
class AwsS3Data(typing_extensions.TypedDict, total=False):
    awsAccessKey: AwsAccessKey
    bucketName: str
    path: str
    roleArn: str

@typing.type_check_only
class AzureBlobStorageData(typing_extensions.TypedDict, total=False):
    azureCredentials: AzureCredentials
    container: str
    path: str
    storageAccount: str

@typing.type_check_only
class AzureCredentials(typing_extensions.TypedDict, total=False):
    sasToken: str

@typing.type_check_only
class BandwidthLimit(typing_extensions.TypedDict, total=False):
    limitMbps: str

@typing.type_check_only
class CancelOperationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Date(typing_extensions.TypedDict, total=False):
    day: int
    month: int
    year: int

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ErrorLogEntry(typing_extensions.TypedDict, total=False):
    errorDetails: _list[str]
    url: str

@typing.type_check_only
class ErrorSummary(typing_extensions.TypedDict, total=False):
    errorCode: typing_extensions.Literal[
        "OK",
        "CANCELLED",
        "UNKNOWN",
        "INVALID_ARGUMENT",
        "DEADLINE_EXCEEDED",
        "NOT_FOUND",
        "ALREADY_EXISTS",
        "PERMISSION_DENIED",
        "UNAUTHENTICATED",
        "RESOURCE_EXHAUSTED",
        "FAILED_PRECONDITION",
        "ABORTED",
        "OUT_OF_RANGE",
        "UNIMPLEMENTED",
        "INTERNAL",
        "UNAVAILABLE",
        "DATA_LOSS",
    ]
    errorCount: str
    errorLogEntries: _list[ErrorLogEntry]

@typing.type_check_only
class GcsData(typing_extensions.TypedDict, total=False):
    bucketName: str
    path: str

@typing.type_check_only
class GoogleServiceAccount(typing_extensions.TypedDict, total=False):
    accountEmail: str
    subjectId: str

@typing.type_check_only
class HttpData(typing_extensions.TypedDict, total=False):
    listUrl: str

@typing.type_check_only
class ListAgentPoolsResponse(typing_extensions.TypedDict, total=False):
    agentPools: _list[AgentPool]
    nextPageToken: str

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class ListTransferJobsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    transferJobs: _list[TransferJob]

@typing.type_check_only
class LoggingConfig(typing_extensions.TypedDict, total=False):
    enableOnpremGcsTransferLogs: bool
    logActionStates: _list[str]
    logActions: _list[str]

@typing.type_check_only
class MetadataOptions(typing_extensions.TypedDict, total=False):
    acl: typing_extensions.Literal[
        "ACL_UNSPECIFIED", "ACL_DESTINATION_BUCKET_DEFAULT", "ACL_PRESERVE"
    ]
    gid: typing_extensions.Literal["GID_UNSPECIFIED", "GID_SKIP", "GID_NUMBER"]
    kmsKey: typing_extensions.Literal[
        "KMS_KEY_UNSPECIFIED", "KMS_KEY_DESTINATION_BUCKET_DEFAULT", "KMS_KEY_PRESERVE"
    ]
    mode: typing_extensions.Literal["MODE_UNSPECIFIED", "MODE_SKIP", "MODE_PRESERVE"]
    storageClass: typing_extensions.Literal[
        "STORAGE_CLASS_UNSPECIFIED",
        "STORAGE_CLASS_DESTINATION_BUCKET_DEFAULT",
        "STORAGE_CLASS_PRESERVE",
        "STORAGE_CLASS_STANDARD",
        "STORAGE_CLASS_NEARLINE",
        "STORAGE_CLASS_COLDLINE",
        "STORAGE_CLASS_ARCHIVE",
    ]
    symlink: typing_extensions.Literal[
        "SYMLINK_UNSPECIFIED", "SYMLINK_SKIP", "SYMLINK_PRESERVE"
    ]
    temporaryHold: typing_extensions.Literal[
        "TEMPORARY_HOLD_UNSPECIFIED", "TEMPORARY_HOLD_SKIP", "TEMPORARY_HOLD_PRESERVE"
    ]
    timeCreated: typing_extensions.Literal[
        "TIME_CREATED_UNSPECIFIED",
        "TIME_CREATED_SKIP",
        "TIME_CREATED_PRESERVE_AS_CUSTOM_TIME",
    ]
    uid: typing_extensions.Literal["UID_UNSPECIFIED", "UID_SKIP", "UID_NUMBER"]

@typing.type_check_only
class NotificationConfig(typing_extensions.TypedDict, total=False):
    eventTypes: _list[str]
    payloadFormat: typing_extensions.Literal[
        "PAYLOAD_FORMAT_UNSPECIFIED", "NONE", "JSON"
    ]
    pubsubTopic: str

@typing.type_check_only
class ObjectConditions(typing_extensions.TypedDict, total=False):
    excludePrefixes: _list[str]
    includePrefixes: _list[str]
    lastModifiedBefore: str
    lastModifiedSince: str
    maxTimeElapsedSinceLastModification: str
    minTimeElapsedSinceLastModification: str

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class PauseTransferOperationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class PosixFilesystem(typing_extensions.TypedDict, total=False):
    rootDirectory: str

@typing.type_check_only
class ResumeTransferOperationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class RunTransferJobRequest(typing_extensions.TypedDict, total=False):
    projectId: str

@typing.type_check_only
class S3CompatibleMetadata(typing_extensions.TypedDict, total=False):
    authMethod: typing_extensions.Literal[
        "AUTH_METHOD_UNSPECIFIED",
        "AUTH_METHOD_AWS_SIGNATURE_V4",
        "AUTH_METHOD_AWS_SIGNATURE_V2",
    ]
    listApi: typing_extensions.Literal[
        "LIST_API_UNSPECIFIED", "LIST_OBJECTS_V2", "LIST_OBJECTS"
    ]
    protocol: typing_extensions.Literal[
        "NETWORK_PROTOCOL_UNSPECIFIED",
        "NETWORK_PROTOCOL_HTTPS",
        "NETWORK_PROTOCOL_HTTP",
    ]
    requestModel: typing_extensions.Literal[
        "REQUEST_MODEL_UNSPECIFIED",
        "REQUEST_MODEL_VIRTUAL_HOSTED_STYLE",
        "REQUEST_MODEL_PATH_STYLE",
    ]

@typing.type_check_only
class Schedule(typing_extensions.TypedDict, total=False):
    endTimeOfDay: TimeOfDay
    repeatInterval: str
    scheduleEndDate: Date
    scheduleStartDate: Date
    startTimeOfDay: TimeOfDay

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class TimeOfDay(typing_extensions.TypedDict, total=False):
    hours: int
    minutes: int
    nanos: int
    seconds: int

@typing.type_check_only
class TransferCounters(typing_extensions.TypedDict, total=False):
    bytesCopiedToSink: str
    bytesDeletedFromSink: str
    bytesDeletedFromSource: str
    bytesFailedToDeleteFromSink: str
    bytesFoundFromSource: str
    bytesFoundOnlyFromSink: str
    bytesFromSourceFailed: str
    bytesFromSourceSkippedBySync: str
    directoriesFailedToListFromSource: str
    directoriesFoundFromSource: str
    directoriesSuccessfullyListedFromSource: str
    intermediateObjectsCleanedUp: str
    intermediateObjectsFailedCleanedUp: str
    objectsCopiedToSink: str
    objectsDeletedFromSink: str
    objectsDeletedFromSource: str
    objectsFailedToDeleteFromSink: str
    objectsFoundFromSource: str
    objectsFoundOnlyFromSink: str
    objectsFromSourceFailed: str
    objectsFromSourceSkippedBySync: str

@typing.type_check_only
class TransferJob(typing_extensions.TypedDict, total=False):
    creationTime: str
    deletionTime: str
    description: str
    lastModificationTime: str
    latestOperationName: str
    loggingConfig: LoggingConfig
    name: str
    notificationConfig: NotificationConfig
    projectId: str
    schedule: Schedule
    status: typing_extensions.Literal[
        "STATUS_UNSPECIFIED", "ENABLED", "DISABLED", "DELETED"
    ]
    transferSpec: TransferSpec

@typing.type_check_only
class TransferManifest(typing_extensions.TypedDict, total=False):
    location: str

@typing.type_check_only
class TransferOperation(typing_extensions.TypedDict, total=False):
    counters: TransferCounters
    endTime: str
    errorBreakdowns: _list[ErrorSummary]
    name: str
    notificationConfig: NotificationConfig
    projectId: str
    startTime: str
    status: typing_extensions.Literal[
        "STATUS_UNSPECIFIED",
        "IN_PROGRESS",
        "PAUSED",
        "SUCCESS",
        "FAILED",
        "ABORTED",
        "QUEUED",
    ]
    transferJobName: str
    transferSpec: TransferSpec

@typing.type_check_only
class TransferOptions(typing_extensions.TypedDict, total=False):
    deleteObjectsFromSourceAfterTransfer: bool
    deleteObjectsUniqueInSink: bool
    metadataOptions: MetadataOptions
    overwriteObjectsAlreadyExistingInSink: bool
    overwriteWhen: typing_extensions.Literal[
        "OVERWRITE_WHEN_UNSPECIFIED", "DIFFERENT", "NEVER", "ALWAYS"
    ]

@typing.type_check_only
class TransferSpec(typing_extensions.TypedDict, total=False):
    awsS3CompatibleDataSource: AwsS3CompatibleData
    awsS3DataSource: AwsS3Data
    azureBlobStorageDataSource: AzureBlobStorageData
    gcsDataSink: GcsData
    gcsDataSource: GcsData
    gcsIntermediateDataLocation: GcsData
    httpDataSource: HttpData
    objectConditions: ObjectConditions
    posixDataSink: PosixFilesystem
    posixDataSource: PosixFilesystem
    sinkAgentPoolName: str
    sourceAgentPoolName: str
    transferManifest: TransferManifest
    transferOptions: TransferOptions

@typing.type_check_only
class UpdateTransferJobRequest(typing_extensions.TypedDict, total=False):
    projectId: str
    transferJob: TransferJob
    updateTransferJobFieldMask: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class PubsubResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class SchemasResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                parent: str,
                body: Schema = ...,
                schemaId: str = ...,
                **kwargs: typing.Any
            ) -> SchemaHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self,
                *,
                name: str,
                view: typing_extensions.Literal[
                    "SCHEMA_VIEW_UNSPECIFIED", "BASIC", "FULL"
                ] = ...,
                **kwargs: typing.Any
            ) -> SchemaHttpRequest: ...
            def getIamPolicy(
                self,
                *,
                resource: str,
                options_requestedPolicyVersion: int = ...,
                **kwargs: typing.Any
            ) -> PolicyHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                view: typing_extensions.Literal[
                    "SCHEMA_VIEW_UNSPECIFIED", "BASIC", "FULL"
                ] = ...,
                **kwargs: typing.Any
            ) -> ListSchemasResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListSchemasResponseHttpRequest,
                previous_response: ListSchemasResponse,
            ) -> ListSchemasResponseHttpRequest | None: ...
            def setIamPolicy(
                self,
                *,
                resource: str,
                body: SetIamPolicyRequest = ...,
                **kwargs: typing.Any
            ) -> PolicyHttpRequest: ...
            def testIamPermissions(
                self,
                *,
                resource: str,
                body: TestIamPermissionsRequest = ...,
                **kwargs: typing.Any
            ) -> TestIamPermissionsResponseHttpRequest: ...
            def validate(
                self,
                *,
                parent: str,
                body: ValidateSchemaRequest = ...,
                **kwargs: typing.Any
            ) -> ValidateSchemaResponseHttpRequest: ...
            def validateMessage(
                self,
                *,
                parent: str,
                body: ValidateMessageRequest = ...,
                **kwargs: typing.Any
            ) -> ValidateMessageResponseHttpRequest: ...

        @typing.type_check_only
        class SnapshotsResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                name: str,
                body: CreateSnapshotRequest = ...,
                **kwargs: typing.Any
            ) -> SnapshotHttpRequest: ...
            def delete(
                self, *, snapshot: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, snapshot: str, **kwargs: typing.Any
            ) -> SnapshotHttpRequest: ...
            def getIamPolicy(
                self,
                *,
                resource: str,
                options_requestedPolicyVersion: int = ...,
                **kwargs: typing.Any
            ) -> PolicyHttpRequest: ...
            def list(
                self,
                *,
                project: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListSnapshotsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListSnapshotsResponseHttpRequest,
                previous_response: ListSnapshotsResponse,
            ) -> ListSnapshotsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: UpdateSnapshotRequest = ...,
                **kwargs: typing.Any
            ) -> SnapshotHttpRequest: ...
            def setIamPolicy(
                self,
                *,
                resource: str,
                body: SetIamPolicyRequest = ...,
                **kwargs: typing.Any
            ) -> PolicyHttpRequest: ...
            def testIamPermissions(
                self,
                *,
                resource: str,
                body: TestIamPermissionsRequest = ...,
                **kwargs: typing.Any
            ) -> TestIamPermissionsResponseHttpRequest: ...

        @typing.type_check_only
        class SubscriptionsResource(googleapiclient.discovery.Resource):
            def acknowledge(
                self,
                *,
                subscription: str,
                body: AcknowledgeRequest = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def create(
                self, *, name: str, body: Subscription = ..., **kwargs: typing.Any
            ) -> SubscriptionHttpRequest: ...
            def delete(
                self, *, subscription: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def detach(
                self, *, subscription: str, **kwargs: typing.Any
            ) -> DetachSubscriptionResponseHttpRequest: ...
            def get(
                self, *, subscription: str, **kwargs: typing.Any
            ) -> SubscriptionHttpRequest: ...
            def getIamPolicy(
                self,
                *,
                resource: str,
                options_requestedPolicyVersion: int = ...,
                **kwargs: typing.Any
            ) -> PolicyHttpRequest: ...
            def list(
                self,
                *,
                project: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListSubscriptionsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListSubscriptionsResponseHttpRequest,
                previous_response: ListSubscriptionsResponse,
            ) -> ListSubscriptionsResponseHttpRequest | None: ...
            def modifyAckDeadline(
                self,
                *,
                subscription: str,
                body: ModifyAckDeadlineRequest = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def modifyPushConfig(
                self,
                *,
                subscription: str,
                body: ModifyPushConfigRequest = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def patch(
                self,
                *,
                name: str,
                body: UpdateSubscriptionRequest = ...,
                **kwargs: typing.Any
            ) -> SubscriptionHttpRequest: ...
            def pull(
                self,
                *,
                subscription: str,
                body: PullRequest = ...,
                **kwargs: typing.Any
            ) -> PullResponseHttpRequest: ...
            def seek(
                self,
                *,
                subscription: str,
                body: SeekRequest = ...,
                **kwargs: typing.Any
            ) -> SeekResponseHttpRequest: ...
            def setIamPolicy(
                self,
                *,
                resource: str,
                body: SetIamPolicyRequest = ...,
                **kwargs: typing.Any
            ) -> PolicyHttpRequest: ...
            def testIamPermissions(
                self,
                *,
                resource: str,
                body: TestIamPermissionsRequest = ...,
                **kwargs: typing.Any
            ) -> TestIamPermissionsResponseHttpRequest: ...

        @typing.type_check_only
        class TopicsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class SnapshotsResource(googleapiclient.discovery.Resource):
                def list(
                    self,
                    *,
                    topic: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListTopicSnapshotsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListTopicSnapshotsResponseHttpRequest,
                    previous_response: ListTopicSnapshotsResponse,
                ) -> ListTopicSnapshotsResponseHttpRequest | None: ...

            @typing.type_check_only
            class SubscriptionsResource(googleapiclient.discovery.Resource):
                def list(
                    self,
                    *,
                    topic: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListTopicSubscriptionsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListTopicSubscriptionsResponseHttpRequest,
                    previous_response: ListTopicSubscriptionsResponse,
                ) -> ListTopicSubscriptionsResponseHttpRequest | None: ...

            def create(
                self, *, name: str, body: Topic = ..., **kwargs: typing.Any
            ) -> TopicHttpRequest: ...
            def delete(
                self, *, topic: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(self, *, topic: str, **kwargs: typing.Any) -> TopicHttpRequest: ...
            def getIamPolicy(
                self,
                *,
                resource: str,
                options_requestedPolicyVersion: int = ...,
                **kwargs: typing.Any
            ) -> PolicyHttpRequest: ...
            def list(
                self,
                *,
                project: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListTopicsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListTopicsResponseHttpRequest,
                previous_response: ListTopicsResponse,
            ) -> ListTopicsResponseHttpRequest | None: ...
            def patch(
                self, *, name: str, body: UpdateTopicRequest = ..., **kwargs: typing.Any
            ) -> TopicHttpRequest: ...
            def publish(
                self, *, topic: str, body: PublishRequest = ..., **kwargs: typing.Any
            ) -> PublishResponseHttpRequest: ...
            def setIamPolicy(
                self,
                *,
                resource: str,
                body: SetIamPolicyRequest = ...,
                **kwargs: typing.Any
            ) -> PolicyHttpRequest: ...
            def testIamPermissions(
                self,
                *,
                resource: str,
                body: TestIamPermissionsRequest = ...,
                **kwargs: typing.Any
            ) -> TestIamPermissionsResponseHttpRequest: ...
            def snapshots(self) -> SnapshotsResource: ...
            def subscriptions(self) -> SubscriptionsResource: ...

        def schemas(self) -> SchemasResource: ...
        def snapshots(self) -> SnapshotsResource: ...
        def subscriptions(self) -> SubscriptionsResource: ...
        def topics(self) -> TopicsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class DetachSubscriptionResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DetachSubscriptionResponse: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ListSchemasResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListSchemasResponse: ...

@typing.type_check_only
class ListSnapshotsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListSnapshotsResponse: ...

@typing.type_check_only
class ListSubscriptionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListSubscriptionsResponse: ...

@typing.type_check_only
class ListTopicSnapshotsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListTopicSnapshotsResponse: ...

@typing.type_check_only
class ListTopicSubscriptionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListTopicSubscriptionsResponse: ...

@typing.type_check_only
class ListTopicsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListTopicsResponse: ...

@typing.type_check_only
class PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Policy: ...

@typing.type_check_only
class PublishResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PublishResponse: ...

@typing.type_check_only
class PullResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PullResponse: ...

@typing.type_check_only
class SchemaHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Schema: ...

@typing.type_check_only
class SeekResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SeekResponse: ...

@typing.type_check_only
class SnapshotHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Snapshot: ...

@typing.type_check_only
class SubscriptionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Subscription: ...

@typing.type_check_only
class TestIamPermissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TestIamPermissionsResponse: ...

@typing.type_check_only
class TopicHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Topic: ...

@typing.type_check_only
class ValidateMessageResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ValidateMessageResponse: ...

@typing.type_check_only
class ValidateSchemaResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ValidateSchemaResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CloudSourceRepositoriesResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ReposResource(googleapiclient.discovery.Resource):
            def create(
                self, *, parent: str, body: Repo = ..., **kwargs: typing.Any
            ) -> RepoHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(self, *, name: str, **kwargs: typing.Any) -> RepoHttpRequest: ...
            def getIamPolicy(
                self,
                *,
                resource: str,
                options_requestedPolicyVersion: int = ...,
                **kwargs: typing.Any
            ) -> PolicyHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListReposResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListReposResponseHttpRequest,
                previous_response: ListReposResponse,
            ) -> ListReposResponseHttpRequest | None: ...
            def patch(
                self, *, name: str, body: UpdateRepoRequest = ..., **kwargs: typing.Any
            ) -> RepoHttpRequest: ...
            def setIamPolicy(
                self,
                *,
                resource: str,
                body: SetIamPolicyRequest = ...,
                **kwargs: typing.Any
            ) -> PolicyHttpRequest: ...
            def sync(
                self, *, name: str, body: SyncRepoRequest = ..., **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def testIamPermissions(
                self,
                *,
                resource: str,
                body: TestIamPermissionsRequest = ...,
                **kwargs: typing.Any
            ) -> TestIamPermissionsResponseHttpRequest: ...

        def getConfig(
            self, *, name: str, **kwargs: typing.Any
        ) -> ProjectConfigHttpRequest: ...
        def updateConfig(
            self,
            *,
            name: str,
            body: UpdateProjectConfigRequest = ...,
            **kwargs: typing.Any
        ) -> ProjectConfigHttpRequest: ...
        def repos(self) -> ReposResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ListReposResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListReposResponse: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Policy: ...

@typing.type_check_only
class ProjectConfigHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ProjectConfig: ...

@typing.type_check_only
class RepoHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Repo: ...

@typing.type_check_only
class TestIamPermissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TestIamPermissionsResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Groups(typing_extensions.TypedDict, total=False):
    allowExternalMembers: str
    allowGoogleCommunication: str
    allowWebPosting: str
    archiveOnly: str
    customFooterText: str
    customReplyTo: str
    customRolesEnabledForSettingsToBeMerged: str
    defaultMessageDenyNotificationText: str
    default_sender: str
    description: str
    email: str
    enableCollaborativeInbox: str
    favoriteRepliesOnTop: str
    includeCustomFooter: str
    includeInGlobalAddressList: str
    isArchived: str
    kind: str
    maxMessageBytes: int
    membersCanPostAsTheGroup: str
    messageDisplayFont: str
    messageModerationLevel: str
    name: str
    primaryLanguage: str
    replyTo: str
    sendMessageDenyNotification: str
    showInGroupDirectory: str
    spamModerationLevel: str
    whoCanAdd: str
    whoCanAddReferences: str
    whoCanApproveMembers: str
    whoCanApproveMessages: str
    whoCanAssignTopics: str
    whoCanAssistContent: str
    whoCanBanUsers: str
    whoCanContactOwner: str
    whoCanDeleteAnyPost: str
    whoCanDeleteTopics: str
    whoCanDiscoverGroup: str
    whoCanEnterFreeFormTags: str
    whoCanHideAbuse: str
    whoCanInvite: str
    whoCanJoin: str
    whoCanLeaveGroup: str
    whoCanLockTopics: str
    whoCanMakeTopicsSticky: str
    whoCanMarkDuplicate: str
    whoCanMarkFavoriteReplyOnAnyTopic: str
    whoCanMarkFavoriteReplyOnOwnTopic: str
    whoCanMarkNoResponseNeeded: str
    whoCanModerateContent: str
    whoCanModerateMembers: str
    whoCanModifyMembers: str
    whoCanModifyTagsAndCategories: str
    whoCanMoveTopicsIn: str
    whoCanMoveTopicsOut: str
    whoCanPostAnnouncements: str
    whoCanPostMessage: str
    whoCanTakeTopics: str
    whoCanUnassignTopic: str
    whoCanUnmarkFavoriteReplyOnAnyTopic: str
    whoCanViewGroup: str
    whoCanViewMembership: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AddFirebaseRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Bucket(typing_extensions.TypedDict, total=False):
    name: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GoogleFirebaseStorageControlplaneV1alphaMigrateLocationDestructivelyMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    lastUpdateTime: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "PENDING",
        "CREATING_TEMP_BUCKET",
        "TRANSFERRING_TO_TEMP",
        "DELETING_SOURCE_BUCKET",
        "CREATING_DESTINATION_BUCKET",
        "TRANSFERRING_TO_DESTINATION",
        "DELETING_TEMP_BUCKET",
        "SUCCEEDED",
        "FAILED",
        "ROLLING_BACK",
        "ROLLED_BACK",
    ]

@typing.type_check_only
class GoogleFirebaseStorageControlplaneV1betaMigrateLocationDestructivelyMetadata(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    lastUpdateTime: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "PENDING",
        "CREATING_TEMP_BUCKET",
        "TRANSFERRING_TO_TEMP",
        "DELETING_SOURCE_BUCKET",
        "CREATING_DESTINATION_BUCKET",
        "TRANSFERRING_TO_DESTINATION",
        "DELETING_TEMP_BUCKET",
        "SUCCEEDED",
        "FAILED",
        "ROLLING_BACK",
        "ROLLED_BACK",
    ]

@typing.type_check_only
class ListBucketsResponse(typing_extensions.TypedDict, total=False):
    buckets: _list[Bucket]
    nextPageToken: str

@typing.type_check_only
class RemoveFirebaseRequest(typing_extensions.TypedDict, total=False): ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1Argon2Parameters(
    typing_extensions.TypedDict, total=False
):
    associatedData: str
    hashLengthBytes: int
    hashType: typing_extensions.Literal[
        "HASH_TYPE_UNSPECIFIED", "ARGON2_D", "ARGON2_ID", "ARGON2_I"
    ]
    iterations: int
    memoryCostKib: int
    parallelism: int
    version: typing_extensions.Literal[
        "VERSION_UNSPECIFIED", "VERSION_10", "VERSION_13"
    ]

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1AutoRetrievalInfo(
    typing_extensions.TypedDict, total=False
):
    appSignatureHash: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1BatchDeleteAccountsRequest(
    typing_extensions.TypedDict, total=False
):
    force: bool
    localIds: _list[str]
    tenantId: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1BatchDeleteAccountsResponse(
    typing_extensions.TypedDict, total=False
):
    errors: _list[GoogleCloudIdentitytoolkitV1BatchDeleteErrorInfo]

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1BatchDeleteErrorInfo(
    typing_extensions.TypedDict, total=False
):
    index: int
    localId: str
    message: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1CreateAuthUriRequest(
    typing_extensions.TypedDict, total=False
):
    appId: str
    authFlowType: str
    context: str
    continueUri: str
    customParameter: dict[str, typing.Any]
    hostedDomain: str
    identifier: str
    oauthConsumerKey: str
    oauthScope: str
    openidRealm: str
    otaApp: str
    providerId: str
    sessionId: str
    tenantId: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1CreateAuthUriResponse(
    typing_extensions.TypedDict, total=False
):
    allProviders: _list[str]
    authUri: str
    captchaRequired: bool
    forExistingProvider: bool
    kind: str
    providerId: str
    registered: bool
    sessionId: str
    signinMethods: _list[str]

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1CreateSessionCookieRequest(
    typing_extensions.TypedDict, total=False
):
    idToken: str
    tenantId: str
    validDuration: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1CreateSessionCookieResponse(
    typing_extensions.TypedDict, total=False
):
    sessionCookie: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1DeleteAccountRequest(
    typing_extensions.TypedDict, total=False
):
    delegatedProjectNumber: str
    idToken: str
    localId: str
    targetProjectId: str
    tenantId: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1DeleteAccountResponse(
    typing_extensions.TypedDict, total=False
):
    kind: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1DownloadAccountResponse(
    typing_extensions.TypedDict, total=False
):
    kind: str
    nextPageToken: str
    users: _list[GoogleCloudIdentitytoolkitV1UserInfo]

AlternativeGoogleCloudIdentitytoolkitV1EmailTemplate = typing_extensions.TypedDict(
    "AlternativeGoogleCloudIdentitytoolkitV1EmailTemplate",
    {
        "body": str,
        "customized": bool,
        "disabled": bool,
        "format": typing_extensions.Literal[
            "EMAIL_BODY_FORMAT_UNSPECIFIED", "PLAINTEXT", "HTML"
        ],
        "from": str,
        "fromDisplayName": str,
        "fromLocalPart": str,
        "locale": str,
        "replyTo": str,
        "subject": str,
    },
    total=False,
)

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1EmailTemplate(
    AlternativeGoogleCloudIdentitytoolkitV1EmailTemplate
): ...

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1ErrorInfo(typing_extensions.TypedDict, total=False):
    index: int
    message: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1FederatedUserIdentifier(
    typing_extensions.TypedDict, total=False
):
    providerId: str
    rawId: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1GetAccountInfoRequest(
    typing_extensions.TypedDict, total=False
):
    delegatedProjectNumber: str
    email: _list[str]
    federatedUserId: _list[GoogleCloudIdentitytoolkitV1FederatedUserIdentifier]
    idToken: str
    initialEmail: _list[str]
    localId: _list[str]
    phoneNumber: _list[str]
    targetProjectId: str
    tenantId: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1GetAccountInfoResponse(
    typing_extensions.TypedDict, total=False
):
    kind: str
    users: _list[GoogleCloudIdentitytoolkitV1UserInfo]

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1GetOobCodeRequest(
    typing_extensions.TypedDict, total=False
):
    androidInstallApp: bool
    androidMinimumVersion: str
    androidPackageName: str
    canHandleCodeInApp: bool
    captchaResp: str
    challenge: str
    continueUrl: str
    dynamicLinkDomain: str
    email: str
    iOSAppStoreId: str
    iOSBundleId: str
    idToken: str
    newEmail: str
    requestType: typing_extensions.Literal[
        "OOB_REQ_TYPE_UNSPECIFIED",
        "PASSWORD_RESET",
        "OLD_EMAIL_AGREE",
        "NEW_EMAIL_ACCEPT",
        "VERIFY_EMAIL",
        "RECOVER_EMAIL",
        "EMAIL_SIGNIN",
        "VERIFY_AND_CHANGE_EMAIL",
        "REVERT_SECOND_FACTOR_ADDITION",
    ]
    returnOobLink: bool
    targetProjectId: str
    tenantId: str
    userIp: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1GetOobCodeResponse(
    typing_extensions.TypedDict, total=False
):
    email: str
    kind: str
    oobCode: str
    oobLink: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1GetProjectConfigResponse(
    typing_extensions.TypedDict, total=False
):
    allowPasswordUser: bool
    apiKey: str
    authorizedDomains: _list[str]
    changeEmailTemplate: GoogleCloudIdentitytoolkitV1EmailTemplate
    dynamicLinksDomain: str
    enableAnonymousUser: bool
    idpConfig: _list[GoogleCloudIdentitytoolkitV1IdpConfig]
    legacyResetPasswordTemplate: GoogleCloudIdentitytoolkitV1EmailTemplate
    projectId: str
    resetPasswordTemplate: GoogleCloudIdentitytoolkitV1EmailTemplate
    revertSecondFactorAdditionTemplate: GoogleCloudIdentitytoolkitV1EmailTemplate
    useEmailSending: bool
    verifyEmailTemplate: GoogleCloudIdentitytoolkitV1EmailTemplate

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1GetRecaptchaParamResponse(
    typing_extensions.TypedDict, total=False
):
    kind: str
    recaptchaSiteKey: str
    recaptchaStoken: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1GetSessionCookiePublicKeysResponse(
    typing_extensions.TypedDict, total=False
):
    keys: _list[GoogleCloudIdentitytoolkitV1OpenIdConnectKey]

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1IdpConfig(typing_extensions.TypedDict, total=False):
    clientId: str
    enabled: bool
    experimentPercent: int
    provider: typing_extensions.Literal[
        "PROVIDER_UNSPECIFIED",
        "MSLIVE",
        "GOOGLE",
        "FACEBOOK",
        "PAYPAL",
        "TWITTER",
        "YAHOO",
        "AOL",
        "GITHUB",
        "GOOGLE_PLAY_GAMES",
        "LINKEDIN",
        "IOS_GAME_CENTER",
    ]
    secret: str
    whitelistedAudiences: _list[str]

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1IssueSamlResponseRequest(
    typing_extensions.TypedDict, total=False
):
    idToken: str
    rpId: str
    samlAppEntityId: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1IssueSamlResponseResponse(
    typing_extensions.TypedDict, total=False
):
    acsEndpoint: str
    email: str
    firstName: str
    isNewUser: bool
    lastName: str
    relayState: str
    samlResponse: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1MfaEnrollment(
    typing_extensions.TypedDict, total=False
):
    displayName: str
    enrolledAt: str
    mfaEnrollmentId: str
    phoneInfo: str
    unobfuscatedPhoneInfo: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1MfaFactor(typing_extensions.TypedDict, total=False):
    displayName: str
    phoneInfo: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1MfaInfo(typing_extensions.TypedDict, total=False):
    enrollments: _list[GoogleCloudIdentitytoolkitV1MfaEnrollment]

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1OpenIdConnectKey(
    typing_extensions.TypedDict, total=False
):
    alg: str
    e: str
    kid: str
    kty: str
    n: str
    use: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1ProviderUserInfo(
    typing_extensions.TypedDict, total=False
):
    displayName: str
    email: str
    federatedId: str
    phoneNumber: str
    photoUrl: str
    providerId: str
    rawId: str
    screenName: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1QueryUserInfoRequest(
    typing_extensions.TypedDict, total=False
):
    expression: _list[GoogleCloudIdentitytoolkitV1SqlExpression]
    limit: str
    offset: str
    order: typing_extensions.Literal["ORDER_UNSPECIFIED", "ASC", "DESC"]
    returnUserInfo: bool
    sortBy: typing_extensions.Literal[
        "SORT_BY_FIELD_UNSPECIFIED",
        "USER_ID",
        "NAME",
        "CREATED_AT",
        "LAST_LOGIN_AT",
        "USER_EMAIL",
    ]
    tenantId: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1QueryUserInfoResponse(
    typing_extensions.TypedDict, total=False
):
    recordsCount: str
    userInfo: _list[GoogleCloudIdentitytoolkitV1UserInfo]

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1ResetPasswordRequest(
    typing_extensions.TypedDict, total=False
):
    email: str
    newPassword: str
    oldPassword: str
    oobCode: str
    tenantId: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1ResetPasswordResponse(
    typing_extensions.TypedDict, total=False
):
    email: str
    kind: str
    mfaInfo: GoogleCloudIdentitytoolkitV1MfaEnrollment
    newEmail: str
    requestType: typing_extensions.Literal[
        "OOB_REQ_TYPE_UNSPECIFIED",
        "PASSWORD_RESET",
        "OLD_EMAIL_AGREE",
        "NEW_EMAIL_ACCEPT",
        "VERIFY_EMAIL",
        "RECOVER_EMAIL",
        "EMAIL_SIGNIN",
        "VERIFY_AND_CHANGE_EMAIL",
        "REVERT_SECOND_FACTOR_ADDITION",
    ]

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1SendVerificationCodeRequest(
    typing_extensions.TypedDict, total=False
):
    autoRetrievalInfo: GoogleCloudIdentitytoolkitV1AutoRetrievalInfo
    iosReceipt: str
    iosSecret: str
    phoneNumber: str
    recaptchaToken: str
    safetyNetToken: str
    tenantId: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1SendVerificationCodeResponse(
    typing_extensions.TypedDict, total=False
):
    sessionInfo: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1SetAccountInfoRequest(
    typing_extensions.TypedDict, total=False
):
    captchaChallenge: str
    captchaResponse: str
    createdAt: str
    customAttributes: str
    delegatedProjectNumber: str
    deleteAttribute: _list[str]
    deleteProvider: _list[str]
    disableUser: bool
    displayName: str
    email: str
    emailVerified: bool
    idToken: str
    instanceId: str
    lastLoginAt: str
    linkProviderUserInfo: GoogleCloudIdentitytoolkitV1ProviderUserInfo
    localId: str
    mfa: GoogleCloudIdentitytoolkitV1MfaInfo
    oobCode: str
    password: str
    phoneNumber: str
    photoUrl: str
    provider: _list[str]
    returnSecureToken: bool
    targetProjectId: str
    tenantId: str
    upgradeToFederatedLogin: bool
    validSince: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1SetAccountInfoResponse(
    typing_extensions.TypedDict, total=False
):
    displayName: str
    email: str
    emailVerified: bool
    expiresIn: str
    idToken: str
    kind: str
    localId: str
    newEmail: str
    passwordHash: str
    photoUrl: str
    providerUserInfo: _list[GoogleCloudIdentitytoolkitV1ProviderUserInfo]
    refreshToken: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1SignInWithCustomTokenRequest(
    typing_extensions.TypedDict, total=False
):
    delegatedProjectNumber: str
    instanceId: str
    returnSecureToken: bool
    tenantId: str
    token: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1SignInWithCustomTokenResponse(
    typing_extensions.TypedDict, total=False
):
    expiresIn: str
    idToken: str
    isNewUser: bool
    kind: str
    refreshToken: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1SignInWithEmailLinkRequest(
    typing_extensions.TypedDict, total=False
):
    email: str
    idToken: str
    oobCode: str
    tenantId: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1SignInWithEmailLinkResponse(
    typing_extensions.TypedDict, total=False
):
    email: str
    expiresIn: str
    idToken: str
    isNewUser: bool
    kind: str
    localId: str
    mfaInfo: _list[GoogleCloudIdentitytoolkitV1MfaEnrollment]
    mfaPendingCredential: str
    refreshToken: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1SignInWithGameCenterRequest(
    typing_extensions.TypedDict, total=False
):
    displayName: str
    idToken: str
    playerId: str
    publicKeyUrl: str
    salt: str
    signature: str
    tenantId: str
    timestamp: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1SignInWithGameCenterResponse(
    typing_extensions.TypedDict, total=False
):
    displayName: str
    expiresIn: str
    idToken: str
    isNewUser: bool
    localId: str
    playerId: str
    refreshToken: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1SignInWithIdpRequest(
    typing_extensions.TypedDict, total=False
):
    autoCreate: bool
    delegatedProjectNumber: str
    idToken: str
    pendingIdToken: str
    pendingToken: str
    postBody: str
    requestUri: str
    returnIdpCredential: bool
    returnRefreshToken: bool
    returnSecureToken: bool
    sessionId: str
    tenantId: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1SignInWithIdpResponse(
    typing_extensions.TypedDict, total=False
):
    context: str
    dateOfBirth: str
    displayName: str
    email: str
    emailRecycled: bool
    emailVerified: bool
    errorMessage: str
    expiresIn: str
    federatedId: str
    firstName: str
    fullName: str
    idToken: str
    inputEmail: str
    isNewUser: bool
    kind: str
    language: str
    lastName: str
    localId: str
    mfaInfo: _list[GoogleCloudIdentitytoolkitV1MfaEnrollment]
    mfaPendingCredential: str
    needConfirmation: bool
    needEmail: bool
    nickName: str
    oauthAccessToken: str
    oauthAuthorizationCode: str
    oauthExpireIn: int
    oauthIdToken: str
    oauthRefreshToken: str
    oauthTokenSecret: str
    originalEmail: str
    pendingToken: str
    photoUrl: str
    providerId: str
    rawUserInfo: str
    refreshToken: str
    screenName: str
    tenantId: str
    timeZone: str
    verifiedProvider: _list[str]

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1SignInWithPasswordRequest(
    typing_extensions.TypedDict, total=False
):
    captchaChallenge: str
    captchaResponse: str
    delegatedProjectNumber: str
    email: str
    idToken: str
    instanceId: str
    password: str
    pendingIdToken: str
    returnSecureToken: bool
    tenantId: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1SignInWithPasswordResponse(
    typing_extensions.TypedDict, total=False
):
    displayName: str
    email: str
    expiresIn: str
    idToken: str
    kind: str
    localId: str
    mfaInfo: _list[GoogleCloudIdentitytoolkitV1MfaEnrollment]
    mfaPendingCredential: str
    oauthAccessToken: str
    oauthAuthorizationCode: str
    oauthExpireIn: int
    profilePicture: str
    refreshToken: str
    registered: bool

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1SignInWithPhoneNumberRequest(
    typing_extensions.TypedDict, total=False
):
    code: str
    idToken: str
    operation: typing_extensions.Literal[
        "VERIFY_OP_UNSPECIFIED", "SIGN_UP_OR_IN", "REAUTH", "UPDATE", "LINK"
    ]
    phoneNumber: str
    sessionInfo: str
    temporaryProof: str
    tenantId: str
    verificationProof: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1SignInWithPhoneNumberResponse(
    typing_extensions.TypedDict, total=False
):
    expiresIn: str
    idToken: str
    isNewUser: bool
    localId: str
    phoneNumber: str
    refreshToken: str
    temporaryProof: str
    temporaryProofExpiresIn: str
    verificationProof: str
    verificationProofExpiresIn: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1SignUpRequest(
    typing_extensions.TypedDict, total=False
):
    captchaChallenge: str
    captchaResponse: str
    disabled: bool
    displayName: str
    email: str
    emailVerified: bool
    idToken: str
    instanceId: str
    localId: str
    mfaInfo: _list[GoogleCloudIdentitytoolkitV1MfaFactor]
    password: str
    phoneNumber: str
    photoUrl: str
    targetProjectId: str
    tenantId: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1SignUpResponse(
    typing_extensions.TypedDict, total=False
):
    displayName: str
    email: str
    expiresIn: str
    idToken: str
    kind: str
    localId: str
    refreshToken: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1SqlExpression(
    typing_extensions.TypedDict, total=False
):
    email: str
    phoneNumber: str
    userId: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1UploadAccountRequest(
    typing_extensions.TypedDict, total=False
):
    allowOverwrite: bool
    argon2Parameters: GoogleCloudIdentitytoolkitV1Argon2Parameters
    blockSize: int
    cpuMemCost: int
    delegatedProjectNumber: str
    dkLen: int
    hashAlgorithm: str
    memoryCost: int
    parallelization: int
    passwordHashOrder: typing_extensions.Literal[
        "UNSPECIFIED_ORDER", "SALT_AND_PASSWORD", "PASSWORD_AND_SALT"
    ]
    rounds: int
    saltSeparator: str
    sanityCheck: bool
    signerKey: str
    tenantId: str
    users: _list[GoogleCloudIdentitytoolkitV1UserInfo]

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1UploadAccountResponse(
    typing_extensions.TypedDict, total=False
):
    error: _list[GoogleCloudIdentitytoolkitV1ErrorInfo]
    kind: str

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1UserInfo(typing_extensions.TypedDict, total=False):
    createdAt: str
    customAttributes: str
    customAuth: bool
    dateOfBirth: str
    disabled: bool
    displayName: str
    email: str
    emailLinkSignin: bool
    emailVerified: bool
    initialEmail: str
    language: str
    lastLoginAt: str
    lastRefreshAt: str
    localId: str
    mfaInfo: _list[GoogleCloudIdentitytoolkitV1MfaEnrollment]
    passwordHash: str
    passwordUpdatedAt: float
    phoneNumber: str
    photoUrl: str
    providerUserInfo: _list[GoogleCloudIdentitytoolkitV1ProviderUserInfo]
    rawPassword: str
    salt: str
    screenName: str
    tenantId: str
    timeZone: str
    validSince: str
    version: int

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1VerifyIosClientRequest(
    typing_extensions.TypedDict, total=False
):
    appToken: str
    isSandbox: bool

@typing.type_check_only
class GoogleCloudIdentitytoolkitV1VerifyIosClientResponse(
    typing_extensions.TypedDict, total=False
):
    receipt: str
    suggestedTimeout: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class NetworkServicesResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class EdgeCacheKeysetsResource(googleapiclient.discovery.Resource):
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...

            @typing.type_check_only
            class EdgeCacheOriginsResource(googleapiclient.discovery.Resource):
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...

            @typing.type_check_only
            class EdgeCacheServicesResource(googleapiclient.discovery.Resource):
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...

            @typing.type_check_only
            class EndpointPoliciesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: EndpointPolicy = ...,
                    endpointPolicyId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EndpointPolicyHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListEndpointPoliciesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListEndpointPoliciesResponseHttpRequest,
                    previous_response: ListEndpointPoliciesResponse,
                ) -> ListEndpointPoliciesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: EndpointPolicy = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...

            @typing.type_check_only
            class GatewaysResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: Gateway = ...,
                    gatewayId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GatewayHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListGatewaysResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListGatewaysResponseHttpRequest,
                    previous_response: ListGatewaysResponse,
                ) -> ListGatewaysResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: Gateway = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...

            @typing.type_check_only
            class GrpcRoutesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GrpcRoute = ...,
                    grpcRouteId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GrpcRouteHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListGrpcRoutesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListGrpcRoutesResponseHttpRequest,
                    previous_response: ListGrpcRoutesResponse,
                ) -> ListGrpcRoutesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GrpcRoute = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...

            @typing.type_check_only
            class HttpRoutesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: HttpRoute = ...,
                    httpRouteId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> HttpRouteHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListHttpRoutesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListHttpRoutesResponseHttpRequest,
                    previous_response: ListHttpRoutesResponse,
                ) -> ListHttpRoutesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: HttpRoute = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...

            @typing.type_check_only
            class MeshesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: Mesh = ...,
                    meshId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> MeshHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListMeshesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListMeshesResponseHttpRequest,
                    previous_response: ListMeshesResponse,
                ) -> ListMeshesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: Mesh = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...

            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def cancel(
                    self,
                    *,
                    name: str,
                    body: CancelOperationRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def list(
                    self,
                    *,
                    name: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListOperationsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListOperationsResponseHttpRequest,
                    previous_response: ListOperationsResponse,
                ) -> ListOperationsResponseHttpRequest | None: ...

            @typing.type_check_only
            class ServiceBindingsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: ServiceBinding = ...,
                    serviceBindingId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> ServiceBindingHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListServiceBindingsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListServiceBindingsResponseHttpRequest,
                    previous_response: ListServiceBindingsResponse,
                ) -> ListServiceBindingsResponseHttpRequest | None: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...

            @typing.type_check_only
            class TcpRoutesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: TcpRoute = ...,
                    tcpRouteId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> TcpRouteHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListTcpRoutesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListTcpRoutesResponseHttpRequest,
                    previous_response: ListTcpRoutesResponse,
                ) -> ListTcpRoutesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: TcpRoute = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...

            @typing.type_check_only
            class TlsRoutesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: TlsRoute = ...,
                    tlsRouteId: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> TlsRouteHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListTlsRoutesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListTlsRoutesResponseHttpRequest,
                    previous_response: ListTlsRoutesResponse,
                ) -> ListTlsRoutesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: TlsRoute = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...

            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> LocationHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListLocationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListLocationsResponseHttpRequest,
                previous_response: ListLocationsResponse,
            ) -> ListLocationsResponseHttpRequest | None: ...
            def edgeCacheKeysets(self) -> EdgeCacheKeysetsResource: ...
            def edgeCacheOrigins(self) -> EdgeCacheOriginsResource: ...
            def edgeCacheServices(self) -> EdgeCacheServicesResource: ...
            def endpointPolicies(self) -> EndpointPoliciesResource: ...
            def gateways(self) -> GatewaysResource: ...
            def grpcRoutes(self) -> GrpcRoutesResource: ...
            def httpRoutes(self) -> HttpRoutesResource: ...
            def meshes(self) -> MeshesResource: ...
            def operations(self) -> OperationsResource: ...
            def serviceBindings(self) -> ServiceBindingsResource: ...
            def tcpRoutes(self) -> TcpRoutesResource: ...
            def tlsRoutes(self) -> TlsRoutesResource: ...

        def locations(self) -> LocationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class EndpointPolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> EndpointPolicy: ...

@typing.type_check_only
class GatewayHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Gateway: ...

@typing.type_check_only
class GrpcRouteHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GrpcRoute: ...

@typing.type_check_only
class HttpRouteHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> HttpRoute: ...

@typing.type_check_only
class ListEndpointPoliciesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListEndpointPoliciesResponse: ...

@typing.type_check_only
class ListGatewaysResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListGatewaysResponse: ...

@typing.type_check_only
class ListGrpcRoutesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListGrpcRoutesResponse: ...

@typing.type_check_only
class ListHttpRoutesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListHttpRoutesResponse: ...

@typing.type_check_only
class ListLocationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListLocationsResponse: ...

@typing.type_check_only
class ListMeshesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListMeshesResponse: ...

@typing.type_check_only
class ListOperationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListOperationsResponse: ...

@typing.type_check_only
class ListServiceBindingsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListServiceBindingsResponse: ...

@typing.type_check_only
class ListTcpRoutesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListTcpRoutesResponse: ...

@typing.type_check_only
class ListTlsRoutesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListTlsRoutesResponse: ...

@typing.type_check_only
class LocationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Location: ...

@typing.type_check_only
class MeshHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Mesh: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Policy: ...

@typing.type_check_only
class ServiceBindingHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ServiceBinding: ...

@typing.type_check_only
class TcpRouteHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TcpRoute: ...

@typing.type_check_only
class TestIamPermissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TestIamPermissionsResponse: ...

@typing.type_check_only
class TlsRouteHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TlsRoute: ...
